STBottomSheetButton class

Inheritance

Constructors

STBottomSheetButton({Key? key, double contentHeight = 200.0, required Widget child, required Widget content, EdgeInsetsGeometry? buttonPadding = const EdgeInsets.all(15), BoxDecoration? buttonStyle, double buttonHeight = 50, BoxDecoration? contentStyle, double buttonWidth = 150, EdgeInsetsGeometry? contentPadding = const EdgeInsets.all(10), Alignment buttonAlignment = Alignment.center, bool showDragHandle = true, Color sheetBackgroundColor = Colors.white})
const

Properties

buttonAlignment Alignment
final
buttonHeight double
final
buttonPadding EdgeInsetsGeometry?
final
buttonStyle BoxDecoration?
final
buttonWidth double
final
child Widget
final
content Widget
final
contentHeight double
final
contentPadding EdgeInsetsGeometry?
final
contentStyle BoxDecoration?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sheetBackgroundColor Color
final
showDragHandle bool
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<STBottomSheetButton>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited